public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: Ingo Molnar <mingo@kernel.org>
To: linux-kernel@vger.kernel.org
Cc: Juergen Gross <jgross@suse.com>,
	"H . Peter Anvin" <hpa@zytor.com>,
	Linus Torvalds <torvalds@linux-foundation.org>,
	Peter Zijlstra <peterz@infradead.org>,
	Borislav Petkov <bp@alien8.de>,
	Thomas Gleixner <tglx@linutronix.de>,
	Ingo Molnar <mingo@kernel.org>
Subject: [PATCH 07/53] x86/alternatives: Rename 'poke_int3_handler()' to 'smp_text_poke_int3_handler()'
Date: Fri, 11 Apr 2025 07:40:19 +0200	[thread overview]
Message-ID: <20250411054105.2341982-8-mingo@kernel.org> (raw)
In-Reply-To: <20250411054105.2341982-1-mingo@kernel.org>

All related functions in this subsystem already have a
text_poke_int3_ prefix - add it to the trap handler
as well.

Signed-off-by: Ingo Molnar <mingo@kernel.org>
---
 arch/x86/include/asm/text-patching.h | 2 +-
 arch/x86/kernel/alternative.c        | 2 +-
 arch/x86/kernel/traps.c              | 6 +++---
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/arch/x86/include/asm/text-patching.h b/arch/x86/include/asm/text-patching.h
index 5189188b5e49..93a6b7bc78bd 100644
--- a/arch/x86/include/asm/text-patching.h
+++ b/arch/x86/include/asm/text-patching.h
@@ -38,7 +38,7 @@ extern void *text_poke_copy(void *addr, const void *opcode, size_t len);
 #define text_poke_copy text_poke_copy
 extern void *text_poke_copy_locked(void *addr, const void *opcode, size_t len, bool core_ok);
 extern void *text_poke_set(void *addr, int c, size_t len);
-extern int poke_int3_handler(struct pt_regs *regs);
+extern int smp_text_poke_int3_handler(struct pt_regs *regs);
 extern void smp_text_poke_single(void *addr, const void *opcode, size_t len, const void *emulate);
 
 extern void text_poke_queue(void *addr, const void *opcode, size_t len, const void *emulate);
diff --git a/arch/x86/kernel/alternative.c b/arch/x86/kernel/alternative.c
index 826c389b22eb..44269d8bf492 100644
--- a/arch/x86/kernel/alternative.c
+++ b/arch/x86/kernel/alternative.c
@@ -2515,7 +2515,7 @@ static __always_inline int patch_cmp(const void *key, const void *elt)
 	return 0;
 }
 
-noinstr int poke_int3_handler(struct pt_regs *regs)
+noinstr int smp_text_poke_int3_handler(struct pt_regs *regs)
 {
 	struct int3_patching_desc *desc;
 	struct text_poke_loc *tp;
diff --git a/arch/x86/kernel/traps.c b/arch/x86/kernel/traps.c
index 9f88b8a78e50..d67407c623f3 100644
--- a/arch/x86/kernel/traps.c
+++ b/arch/x86/kernel/traps.c
@@ -882,16 +882,16 @@ static void do_int3_user(struct pt_regs *regs)
 DEFINE_IDTENTRY_RAW(exc_int3)
 {
 	/*
 	 * poke_int3_handler() is completely self contained code; it does (and
 	 * must) *NOT* call out to anything, lest it hits upon yet another
 	 * INT3.
 	 */
-	if (poke_int3_handler(regs))
+	if (smp_text_poke_int3_handler(regs))
 		return;
 
 	/*
 	 * irqentry_enter_from_user_mode() uses static_branch_{,un}likely()
 	 * and therefore can trigger INT3, hence poke_int3_handler() must
 	 * be done before. If the entry came from kernel mode, then use
 	 * nmi_enter() because the INT3 could have been hit in any context
 	 * including NMI.
@@ -882,16 +882,16 @@ static void do_int3_user(struct pt_regs *regs)
 {
 	/*
-	 * poke_int3_handler() is completely self contained code; it does (and
+	 * smp_text_poke_int3_handler() is completely self contained code; it does (and
 	 * must) *NOT* call out to anything, lest it hits upon yet another
 	 * INT3.
@@ -882,16 +882,16 @@ static void do_int3_user(struct pt_regs *regs)
 	/*
 	 * irqentry_enter_from_user_mode() uses static_branch_{,un}likely()
-	 * and therefore can trigger INT3, hence poke_int3_handler() must
+	 * and therefore can trigger INT3, hence smp_text_poke_int3_handler() must
 	 * be done before. If the entry came from kernel mode, then use
 	 * nmi_enter() because the INT3 could have been hit in any context
-- 
2.45.2


  parent reply	other threads:[~2025-04-11  5:41 UTC|newest]

Thread overview: 105+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-04-11  5:40 [PATCH -v3 00/53] Simplify, reorganize and clean up the x86 text-patching code (alternative.c) Ingo Molnar
2025-04-11  5:40 ` [PATCH 01/53] x86/alternatives: Improve code-patching scalability by removing false sharing in poke_int3_handler() Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Eric Dumazet
2025-04-11  5:40 ` [PATCH 02/53] x86/alternatives: Document the text_poke_bp_batch() synchronization rules a bit more Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Peter Zijlstra
2025-04-11  5:40 ` [PATCH 03/53] x86/alternatives: Rename 'struct bp_patching_desc' to 'struct int3_patching_desc' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] x86/alternatives: Rename 'struct bp_patching_desc' to 'struct text_poke_int3_vec' tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 04/53] x86/alternatives: Rename 'bp_refs' to 'int3_refs' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] x86/alternatives: Rename 'bp_refs' to 'text_poke_array_refs' tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 05/53] x86/alternatives: Rename 'text_poke_bp_batch()' to 'smp_text_poke_batch_process()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 06/53] x86/alternatives: Rename 'text_poke_bp()' to 'smp_text_poke_single()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` Ingo Molnar [this message]
2025-04-11 10:02   ` [tip: x86/alternatives] x86/alternatives: Rename 'poke_int3_handler()' to 'smp_text_poke_int3_handler()' tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 08/53] x86/alternatives: Rename 'poking_mm' to 'text_poke_mm' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 09/53] x86/alternatives: Rename 'poking_addr' to 'text_poke_mm_addr' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 10/53] x86/alternatives: Rename 'bp_desc' to 'int3_desc' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 11/53] x86/alternatives: Remove duplicate 'text_poke_early()' prototype Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 12/53] x86/alternatives: Update comments in int3_emulate_push() Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 13/53] x86/alternatives: Remove the confusing, inaccurate & unnecessary 'temp_mm_state_t' abstraction Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 14/53] x86/alternatives: Rename 'text_poke_flush()' to 'smp_text_poke_batch_flush()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 15/53] x86/alternatives: Rename 'text_poke_finish()' to 'smp_text_poke_batch_finish()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 16/53] x86/alternatives: Rename 'text_poke_queue()' to 'smp_text_poke_batch_add()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 17/53] x86/alternatives: Rename 'text_poke_loc_init()' to 'text_poke_int3_loc_init()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 18/53] x86/alternatives: Rename 'struct text_poke_loc' to 'struct smp_text_poke_loc' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 19/53] x86/alternatives: Rename 'struct int3_patching_desc' to 'struct text_poke_int3_vec' Ingo Molnar
2025-04-11  5:40 ` [PATCH 20/53] x86/alternatives: Rename 'int3_desc' to 'int3_vec' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 21/53] x86/alternatives: Add text_mutex) assert to smp_text_poke_batch_flush() Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 22/53] x86/alternatives: Use non-inverted logic instead of 'tp_order_fail()' Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 23/53] x86/alternatives: Remove the 'addr == NULL means forced-flush' hack from smp_text_poke_batch_finish()/smp_text_poke_batch_flush()/text_poke_addr_ordered() Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 24/53] x86/alternatives: Simplify smp_text_poke_single() by using tp_vec and existing APIs Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 25/53] x86/alternatives: Assert that smp_text_poke_int3_handler() can only ever handle 'tp_vec[]' based requests Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 26/53] x86/alternatives: Assert input parameters in smp_text_poke_batch_process() Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 27/53] x86/alternatives: Introduce 'struct smp_text_poke_array' and move tp_vec and tp_vec_nr to it Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 28/53] x86/alternatives: Remove the tp_vec indirection Ingo Molnar
2025-04-11 10:02   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 29/53] x86/alternatives: Rename 'try_get_desc()' to 'try_get_text_poke_array()' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 30/53] x86/alternatives: Rename 'put_desc()' to 'put_text_poke_array()' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 31/53] x86/alternatives: Simplify try_get_text_poke_array() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 32/53] x86/alternatives: Simplify smp_text_poke_int3_handler() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 33/53] x86/alternatives: Simplify smp_text_poke_batch_process() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 34/53] x86/alternatives: Rename 'int3_refs' to 'text_poke_array_refs' Ingo Molnar
2025-04-11  5:40 ` [PATCH 35/53] x86/alternatives: Move the text_poke_array manipulation into text_poke_int3_loc_init() and rename it to __smp_text_poke_batch_add() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 36/53] x86/alternatives: Remove the mixed-patching restriction on smp_text_poke_single() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 37/53] x86/alternatives: Document 'smp_text_poke_single()' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 38/53] x86/alternatives: Add documentation for smp_text_poke_batch_add() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 39/53] x86/alternatives: Move text_poke_array completion from smp_text_poke_batch_finish() and smp_text_poke_batch_flush() to smp_text_poke_batch_process() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 40/53] x86/alternatives: Rename 'text_poke_sync()' to 'smp_text_poke_sync_each_cpu()' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 41/53] x86/alternatives: Simplify text_poke_addr_ordered() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 42/53] x86/alternatives: Constify text_poke_addr() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 43/53] x86/alternatives: Simplify and clean up patch_cmp() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 44/53] x86/alternatives: Standardize on 'tpl' local variable names for 'struct smp_text_poke_loc *' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 45/53] x86/alternatives: Rename 'TP_ARRAY_NR_ENTRIES_MAX' to 'TEXT_POKE_ARRAY_MAX' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 46/53] x86/alternatives: Rename 'POKE_MAX_OPCODE_SIZE' to 'TEXT_POKE_MAX_OPCODE_SIZE' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:40 ` [PATCH 47/53] x86/alternatives: Simplify the #include section Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:41 ` [PATCH 48/53] x86/alternatives: Move declarations of vmlinux.lds.S defined section symbols to <asm/alternative.h> Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:41 ` [PATCH 49/53] x86/alternatives: Remove 'smp_text_poke_batch_flush()' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:41 ` [PATCH 50/53] x86/alternatives: Update the comments in smp_text_poke_batch_process() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:41 ` [PATCH 51/53] x86/alternatives: Rename 'apply_relocation()' to 'text_poke_apply_relocation()' Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:41 ` [PATCH 52/53] x86/alternatives: Add comment about noinstr expectations Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Ingo Molnar
2025-04-11  5:41 ` [PATCH 53/53] x86/alternatives: Make smp_text_poke_batch_process() subsume smp_text_poke_batch_finish() Ingo Molnar
2025-04-11 10:01   ` [tip: x86/alternatives] " tip-bot2 for Nikolay Borisov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20250411054105.2341982-8-mingo@kernel.org \
    --to=mingo@kernel.org \
    --cc=bp@alien8.de \
    --cc=hpa@zytor.com \
    --cc=jgross@suse.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=peterz@infradead.org \
    --cc=tglx@linutronix.de \
    --cc=torvalds@linux-foundation.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox